@@ -1,4 +1,8 @@
-""" This module provides API to access YAML formatted configuration.
+"""
+
+    configure -- configuration machinery on top of YAML
+    ===================================================
+
 """
 
 import sys
@@ -253,6 +257,8 @@ def configure_logging(logcfg=None, disable_existing_loggers=True):
     else:
         logcfg = {}
 
+    logcfg = dict(logcfg)
+
     if not "version" in logcfg:
         logcfg["version"] = 1
 
